package VMOMI::DistributedVirtualSwitchPortConnecteeConnecteeType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
